<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>Nom de la carte</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="38"/>
        <source>Profile:</source>
        <translation>Profil :</translation>
    </message>
    <message>
        <location filename="../../cardwidget.cc" line="66"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>Échec de pa_context_set_card_profile_by_index()</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%1% (%2dB)</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%1%</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;Muet&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;Min&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;100% (0dB)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Dialogue</translation>
    </message>
    <message>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation type="vanished">&lt;b&gt;avant-gauche&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;small&gt;50%&lt;/small&gt;</source>
        <translation type="vanished">&lt;small&gt;50%&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>Titre du périphérique</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>Audio muette</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>Verrouiller les canaux ensemble</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>Définir comme repli</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Port :&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>Afficher les options avancées</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>AC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>EAC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>DTS</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>MPEG</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Offset de la latence :&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="40"/>
        <source>Rename device...</source>
        <translation>Renommer le périphérique...</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="154"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>échec de pa_context_set_port_latency_offset()</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="225"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>Désolé, mais renommer le périphérique n&apos;est pas possible.</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="226"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>Vous devez charger module-device-manager dans le serveur PulseAudio afin de pouvoir renommer les périphériques</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="232"/>
        <source>Rename device %1 to:</source>
        <translation>Renommer le périphérique %1 an :</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="239"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>Echec de pa_ext_device_manager_set_device_description()</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>Contrôle du volume</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>&amp;Lecture</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucune application ne joue actuellement du son.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="66"/>
        <location filename="../../mainwindow.ui" line="131"/>
        <location filename="../../mainwindow.ui" line="196"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>Afficher :</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="74"/>
        <location filename="../../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>Tous les flux</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="79"/>
        <location filename="../../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="84"/>
        <location filename="../../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>Flux virtuels</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;Enregistrement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucune application n&apos;enregistre actuellement du son.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>Périphériques de _s&amp;ortie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucun périphérique de sortie disponible&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>Tous les périphériques de sortie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>Périphériques de sortie matériels</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>Périphériques de sortie virtuels</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>Périphériques d&apos;&amp;entrée</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucun périphérique d&apos;entrée disponible&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>Tous les périphériques d&apos;entrée</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>Tous, excepté les écrans</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>Périphériques d&apos;entrée matériels</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>Périphériques d&apos;entrée virtuels</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>Écrans</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Configuration</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;Aucune carte n&apos;est disponible pour la configuration&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>Afficher les volumemètres</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (enfiché)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="163"/>
        <location filename="../../mainwindow.cc" line="257"/>
        <source> (unavailable)</source>
        <translation> (non disponible)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="165"/>
        <location filename="../../mainwindow.cc" line="254"/>
        <source> (unplugged)</source>
        <translation> (non enfiché)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="386"/>
        <source>Failed to read data from stream</source>
        <translation>Échec de la lecture de données du flux</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="430"/>
        <source>Peak detect</source>
        <translation>Détection de crêtes</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="431"/>
        <source>Failed to create monitoring stream</source>
        <translation>Échec de la création du flux de surveillance</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="446"/>
        <source>Failed to connect monitoring stream</source>
        <translation>Échec de la connexion au flux de surveillance</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="585"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>Ignore la chute de l&apos;entrée parce qu&apos;elle est désignée comme un événement et donc géré par le widget des événements</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="757"/>
        <source>System Sounds</source>
        <translation>Sons système</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="1088"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>Établissement de la connexion avec PulseAudio. Patientez ...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../pavucontrol.cc" line="67"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="88"/>
        <source>Card callback failure</source>
        <translation>Échec de la fonction de rappel de la carte</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="111"/>
        <source>Sink callback failure</source>
        <translation>Échec du rappel de la destination</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="134"/>
        <source>Source callback failure</source>
        <translation>Échec du rappel de la source</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="153"/>
        <source>Sink input callback failure</source>
        <translation>Échec du rappel de l&apos;entrée de la destination</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="172"/>
        <source>Source output callback failure</source>
        <translation>Échec du rappel de la sortie de la source</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="212"/>
        <source>Client callback failure</source>
        <translation>Échec du rappel du client</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="228"/>
        <source>Server info callback failure</source>
        <translation>Échec du rappel des informations sur le serveur</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="246"/>
        <location filename="../../pavucontrol.cc" line="543"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>Impossible d&apos;initialiser l&apos;extension stream_restore : %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="264"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>Échec de pa_ext_stream_restore_read()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="282"/>
        <location filename="../../pavucontrol.cc" line="557"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>Échec d&apos;initialisation de l&apos;extension de la restauration du périphérique : %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="303"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>Échec de pa_ext_device_restore_read_sink_formats()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="321"/>
        <location filename="../../pavucontrol.cc" line="570"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>Échec de l&apos;initialisation de l&apos;extension du gestionnaire de périphérique : %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="340"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>Échec de pa_ext_device_manager_read()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="357"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>Échec de pa_context_get_sink_info_by_index()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="370"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>Échec de pa_context_get_source_info_by_index()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="383"/>
        <location filename="../../pavucontrol.cc" line="396"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>Échec de pa_context_get_sink_input_info()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="409"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>Échec de pa_context_get_client_info()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="419"/>
        <location filename="../../pavucontrol.cc" line="484"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>Échec de pa_context_get_server_info()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="432"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>Échec de pa_context_get_card_info_by_index()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="475"/>
        <source>pa_context_subscribe() failed</source>
        <translation>Échec de pa_context_subscribe()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="491"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>Échec de pa_context_client_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="498"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>Échec de pa_context_get_card_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="505"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>Échec de pa_context_get_sink_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="512"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>Échec de pa_context_get_source_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="519"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>Échec de pa_context_get_sink_input_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="526"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>Échec de pa_context_get_source_output_info_list()</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="585"/>
        <location filename="../../pavucontrol.cc" line="636"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>Échec de la connexion, essai de reconnection</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="608"/>
        <location filename="../../pavucontrol.cc" line="668"/>
        <source>PulseAudio Volume Control</source>
        <translation>Contrôle du volume PulseAudio</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="623"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s

In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
or default-server in client.conf is misconfigured.
This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
run start-pulseaudio-x11 manually.</source>
        <translation>Échec de la connexion à PulseAudio. Nouvelle tentative dans 5s

Dans ce cas probablement parce que PULSE_SERVER est mal configuré dans la fenêtre Propriétés Environnement / X11,
ou que le serveur par défaut-dans client.conf est mal configuré.
Cette situation peut également survenir lorsque PulseAudio est écrasé et a laissé les détails obsolètes dans la fenêtre X11.
Dans ce cas PulseAudio devrait auto-engendrer à nouveau, ou si ce n&apos;est pas configuré vous ne devriez
exécuter start-pulseaudio-x11 manuellement.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="676"/>
        <source>Select a specific tab on load.</source>
        <translation>Sélectionnez un onglet spécifique lors du chargement.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="679"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>Toujours réessayer si pa quitte (toutes les 5s).</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="682"/>
        <source>Maximize the window.</source>
        <translation>Maximiser la fenêtre.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="707"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>Erreur fatale : connexion impossible à PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>Échec de pa_ext_stream_restore_write()</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="53"/>
        <source>Unknown output</source>
        <translation>Sortie inconnue</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="64"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>Échec de pa_context_set_sink_input_volume()</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="79"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>Échec de pa_context_set_sink_input_mute()</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="89"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>Échec de pa_context_kill_sink_input()</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="114"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>Échec de pa_context_move_sink_input_by_index()</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>Échec de pa_context_set_sink_volume_by_index()</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>Échec de pa_context_set_sink_mute_by_index()</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>Échec de pa_context_set_default_sink()</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>Échec de pa_context_set_sink_port_by_index()</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>Échec de pa_ext_device_restore_save_sink_formats()</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="36"/>
        <source>from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="60"/>
        <source>Unknown input</source>
        <translation>Entrée inconnue</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="72"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>Échec de pa_context_set_source_output_volume()</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="87"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>Échec de pa_context_set_source_output_mute()</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="98"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>Échec de pa_context_kill_source_output()</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="125"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>Échec de pa_context_move_source_output_by_index()</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>Échec de pa_context_set_source_volume_by_index()</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>Échec de pa_context_set_source_mute_by_index()</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>Échec de pa_context_set_default_source()</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>Échec de pa_context_set_source_port_by_index()</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>Titre du périphérique</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>direction</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>périphérique</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>Audio muette</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>Verrouiller les canaux ensembles</translation>
    </message>
    <message>
        <location filename="../../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>Terminer la lecture</translation>
    </message>
</context>
</TS>
